import * as _babel_core from '@babel/core';
import { InputTargets, Targets } from '@babel/helper-compilation-targets';

declare const ModulesOption: {
    readonly false: false;
    readonly auto: "auto";
    readonly amd: "amd";
    readonly commonjs: "commonjs";
    readonly cjs: "cjs";
    readonly systemjs: "systemjs";
    readonly umd: "umd";
};
declare const UseBuiltInsOption: {
    readonly false: false;
    readonly entry: "entry";
    readonly usage: "usage";
};

// Options
// Use explicit modules to prevent typo errors.
type ModuleOption = (typeof ModulesOption)[keyof typeof ModulesOption];
type BuiltInsOption =
  (typeof UseBuiltInsOption)[keyof typeof UseBuiltInsOption];

type CorejsVersion = 2 | 3 | string;

type CorejsOption =
  | false
  | CorejsVersion
  | {
      version: CorejsVersion;
      proposals: boolean;
    };

type PluginListItem = string | RegExp;
type PluginListOption = Array<PluginListItem>;

type Options = {
  bugfixes: boolean;
  configPath: string;
  corejs: CorejsOption;
  debug: boolean;
  exclude: PluginListOption;
  forceAllTransforms: boolean;
  ignoreBrowserslistConfig: boolean;
  include: PluginListOption;
  modules: ModuleOption;
  shippedProposals: boolean;
  targets: {
    uglify?: boolean;
    esmodules?: boolean;
  } & InputTargets;
  useBuiltIns: BuiltInsOption;
  browserslistEnv: string;

  // TODO(Babel 8): Remove these options
  loose: boolean;
  spec: boolean;
};

declare function isPluginRequired(targets: Targets, support: Targets): boolean;
declare const transformIncludesAndExcludes: (opts: Array<string>) => any;
declare const _default: (api: _babel_core.PresetAPI, options: Options, dirname: string) => _babel_core.PresetObject;

export { type Options, _default as default, isPluginRequired, transformIncludesAndExcludes };
